==> daisyui-4.12.4-sources.jar: package/README.md <==
<div align="center">

[![][logo-url]][docs-url]

**The most popular, free and open-source component library for Tailwind CSS**

[![][version]](https://www.npmjs.com/package/daisyui)
[![][commit]](https://github.com/saadeghi/daisyui)
[![][license]](https://github.com/saadeghi/daisyui/blob/master/LICENSE)  
[![][stars]](https://github.com/saadeghi/daisyui)
[![][installs]](https://www.npmjs.com/package/daisyui)
[![][jsdelivr]](https://cdn.jsdelivr.net/npm/daisyui/dist/full.min.css)  
[![][discord]](https://daisyui.com/discord/)
[![][opencollectivebadge]](https://opencollective.com/daisyui)

</div>

# daisyUI 4

### 🌼 [Official website →](https://daisyui.com/)

### 🌼 [See all components →](https://daisyui.com/components/)

### 🌼 [How to use →](https://daisyui.com/docs/install/)

## Community

<div align="center">

Premium Sponsors  
[![][sponsors]][opencollective]

Backers  
[![][backers_org]][opencollective]  
[![][backers]][opencollective]

Contributors
[![][contributors_img]][contributors]

</div>

<div align="center">
  
  
༼ つ ◕_◕ ༽つ  Please share  
  
[![][tweet]](https://twitter.com/intent/tweet?text=daisyUI%20%0D%0AComponents%20for%20Tailwind%20CSS%20%0D%0Ahttps://github.com/saadeghi/daisyui)

</div>

[version]: https://badgen.net/github/tag/saadeghi/daisyui?label=Version&color=1AD1A5
[commit]: https://badgen.net/github/last-commit/saadeghi/daisyui?label=Last%20commit&color=1AD1A5
[license]: https://badgen.net/github/license/saadeghi/daisyui?label=License&color=1AD1A5
[stars]: https://badgen.net/github/stars/saadeghi/daisyui?label=GitHub%20stars&color=1AD1A5
[installs]: https://badgen.net/npm/dt/daisyui?label=NPM%20installs&color=1AD1A5
[jsdelivr]: https://badgen.net/jsdelivr/hits/npm/daisyui?color=1AD1A5
[discord]: https://badgen.net/discord/members/S6TZxycVHs?label=Discord&color=1AD1A5
[opencollectivebadge]: https://badgen.net/opencollective/backers/daisyui?label=Open%20Collective&color=1AD1A5
[tweet]: https://img.shields.io/twitter/url?label=Share&url=https%3A%2F%2Fgithub.com%2Fsaadeghi%2Fdaisyui
[docs-url]: https://daisyui.com/
[logo-url]: https://raw.githubusercontent.com/saadeghi/daisyui-images/master/images/daisyui-logo/favicon-192.png
[opencollective]: https://opencollective.com/daisyui
[sponsors]: https://opencollective.com/daisyui/tiers/premium-sponsor.svg?button=false&avatarHeight=60
[backers]: https://opencollective.com/daisyui/backers.svg?button=false&width=978&avatarHeight=36
[backers_org]: https://opencollective.com/daisyui/organizations.svg?button=false&avatarHeight=36
[contribute]: https://github.com/saadeghi/daisyui/blob/master/.github/CONTRIBUTING.md
[contributors_img]: https://contrib.rocks/image?repo=saadeghi/daisyui&columns=25&anon=1&max=300
[contributors]: https://github.com/saadeghi/daisyui/graphs/contributors

==> daisyui-5.0.18-sources.jar: package/README.md <==
<div align="center">

[![][logo-url]][docs-url]

**The most popular, free and open-source component library for Tailwind CSS**

[![][version]](https://www.npmjs.com/package/daisyui)
[![][commit]](https://github.com/saadeghi/daisyui)
[![][license]](https://github.com/saadeghi/daisyui/blob/master/LICENSE)
[![][stars]](https://github.com/saadeghi/daisyui)
[![][installs]](https://www.npmjs.com/package/daisyui)
[![][jsdelivr]](https://cdn.jsdelivr.net/npm/daisyui@5)
[![][discord]](https://daisyui.com/discord/)
[![][opencollectivebadge]](https://opencollective.com/daisyui)

</div>

# daisyUI 5

### 🌼 [Official website →](https://daisyui.com/)

### 🌼 [See all components →](https://daisyui.com/components/)

### 🌼 [How to use →](https://daisyui.com/docs/install/)

---

[version]: https://badgen.net/github/tag/saadeghi/daisyui?label=Version&color=1AD1A5
[commit]: https://badgen.net/github/last-commit/saadeghi/daisyui?label=Last%20commit&color=1AD1A5
[license]: https://badgen.net/github/license/saadeghi/daisyui?label=License&color=1AD1A5
[stars]: https://badgen.net/github/stars/saadeghi/daisyui?label=GitHub%20stars&color=1AD1A5
[installs]: https://badgen.net/npm/dt/daisyui?label=NPM%20installs&color=1AD1A5
[jsdelivr]: https://badgen.net/jsdelivr/hits/npm/daisyui?color=1AD1A5
[discord]: https://badgen.net/discord/members/S6TZxycVHs?label=Discord&color=1AD1A5
[opencollectivebadge]: https://badgen.net/opencollective/backers/daisyui?label=Open%20Collective&color=1AD1A5
[docs-url]: https://daisyui.com/
[logo-url]: https://raw.githubusercontent.com/saadeghi/daisyui-images/master/images/daisyui-logo/favicon-192.png
